==> dvlp-14.3.0-beta.1.tgz: package/application-worker.js <==
import { createRequire as createRequireBecauseEsbuild } from 'module'; 
const require = createRequireBecauseEsbuild(import.meta.url);

// src/application-host/application-worker.js
import http2 from "http";

// src/utils/broken-named-exports.js
var broken_named_exports_default = {
  react: [
    "Children",
    "Component",
    "Fragment",
    "Profiler",
    "PureComponent",
    "StrictMode",
    "Suspense",
    "__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED",
    "cloneElement",
    "createContext",
    "createElement",
    "createFactory",
    "createRef",
    "forwardRef",
    "isValidElement",
    "lazy",
    "memo",
    "useCallback",
    "useContext",
    "useDebugValue",
    "useEffect",
    "useImperativeHandle",
    "useLayoutEffect",
    "useMemo",
    "useReducer",
    "useRef",
    "useState",
    "version"
  ],
  "react-dom": [
    "__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED",
    "createPortal",
    "findDOMNode",
    "flushSync",
    "hydrate",
    "render",
    "unmountComponentAtNode",
    "unstable_batchedUpdates",
    "unstable_createPortal",
    "unstable_renderSubtreeIntoContainer",
    "version"
  ],
  "react-is": ["isContextConsumer", "isValidElementType"]
};

// src/config.js
import path from "path";
import { pathToFileURL } from "url";
var DIR_NAME = ".dvlp";
var TESTING = process.env.NODE_ENV === "dvlptest" || process.env.CI != void 0;
var VERSION = "14.3.0-beta.1";
var dirPath = path.resolve(DIR_NAME);
var versionDirPath = path.join(dirPath, VERSION);
var applicationLoaderPath = pathToFileURL(
  path.join(versionDirPath, "app-loader.mjs")
);
var bundleDirName = path.join(DIR_NAME, VERSION, "bundled");
var bundleDirPath = path.resolve(bundleDirName);
var bundleDirMetaPath = path.join(bundleDirPath, "__meta__.json");
var defaultPort = process.env.PORT ? Number(process.env.PORT) : 8080;
var electronEntryPath = pathToFileURL(
  path.join(versionDirPath, "electron-entry.cjs")
);
var config = {
  activePort: defaultPort,
  applicationLoaderPath,
  brokenNamedExportsPackages: broken_named_exports_default,
  bundleDirPath,
  bundleDirMetaPath,
  bundleDirName,
  defaultPort,
  directories: [],
  dirPath,
  dvlpDirPath: path.resolve(DIR_NAME),
  electronEntryPath,
  esbuildTargetByExtension: {
    ".js": "js",
    ".mjs": "js",
    ".cjs": "js",
    ".json": "json",
    ".jsx": "jsx",
    ".ts": "ts",
    ".tsx": "tsx",
    ".mts": "ts",
    ".cts": "ts"
  },
  extensionsByType: {
    css: [".pcss", ".sass", ".scss", ".less", ".styl", ".stylus", ".css"],
    html: [
      ".nunjs",
      ".nunjucks",
      ".hbs",
      ".handlebars",
      ".dust",
      ".html",
      ".htm"
    ],
    js: [".ts", ".mts", ".cts", ".tsx", ".jsx", ".mjs", ".cjs", ".js", ".json"]
  },
  jsMimeTypes: {
    "application/javascript": ["js", "mjs", "cjs", "jsx", "ts", "tsx"]
  },
  latency: 50,
  maxAge: "10m",
  reloadEndpoint: "/dvlpreload",
  serverStartTimeout: TESTING ? 4e3 : 1e4,
  testing: TESTING,
  typesByExtension: {
    ".css": "css",
    ".pcss": "css",
    ".sass": "css",
    ".scss": "css",
    ".less": "css",
    ".styl": "css",
    ".stylus": "css",
    ".html": "html",
    ".htm": "html",
    ".nunjs": "html",
    ".nunjucks": "html",
    ".hbs": "html",
    ".handlebars": "html",
    ".dust": "html",
    ".js": "js",
    ".mjs": "js",
    ".cjs": "js",
    ".json": "js",
    ".jsx": "js",
    ".ts": "js",
    ".tsx": "js",
    ".mts": "js",
    ".cts": "js"
  },
  version: VERSION,
  versionDirPath
};

// src/utils/is.js
import fs from "fs";
import util from "util";
var HAS_UTIL_IS_PROXY = util.types && util.types.isProxy !== void 0;
var RE_LOCALHOST = /localhost|127\.0\.0\.1/;
var realPath = "native" in fs.realpathSync && typeof fs.realpathSync.native === "function" ? fs.realpathSync.native : fs.realpathSync;
function isLocalhost(url) {
  return RE_LOCALHOST.test(url);
}
function isProxy(obj) {
  if (HAS_UTIL_IS_PROXY) {
    return util.types.isProxy(obj);
  } else {
    return obj instanceof Proxy;
  }
}

// src/utils/intercept-client-request.js
import http from "http";
import https from "https";
var clientRequestListeners = /* @__PURE__ */ new Set();
var originalHttpRequest = http.request;
var originalHttpGet = http.get;
var originalHttpsRequest = https.request;
var originalHttpsGet = https.get;
function interceptClientRequest(fn) {
  initInterceptClientRequest();
  clientRequestListeners.add(fn);
  return restoreClientRequest.bind(null, fn);
}
function initInterceptClientRequest() {
  if (!isProxy(http.request)) {
    http.request = new Proxy(http.request, {
      apply: clientRequestApplyTrap("http")
    });
    http.get = new Proxy(http.get, { apply: clientRequestApplyTrap("http") });
    https.request = new Proxy(https.request, {
      apply: clientRequestApplyTrap("https")
    });
    https.get = new Proxy(https.get, {
      apply: clientRequestApplyTrap("https")
    });
  }
}
function restoreClientRequest(fn) {
  clientRequestListeners.delete(fn);
  if (!clientRequestListeners.size) {
    http.request = originalHttpRequest;
    http.get = originalHttpGet;
    https.request = originalHttpsRequest;
    https.get = originalHttpsGet;
  }
}
function clientRequestApplyTrap(protocol) {
  return function apply(target, ctx, args) {
    if (clientRequestListeners.size > 0) {
      let [urlOrOptions, optionsOrCallback, callback] = args;
      let options;
      let url;
      if (typeof urlOrOptions === "string" || urlOrOptions instanceof URL) {
        url = new URL(urlOrOptions);
        options = optionsOrCallback;
      } else {
        url = new URL(getHrefFromRequestOptions(urlOrOptions, protocol));
        callback = optionsOrCallback;
        options = urlOrOptions;
      }
      if (notifyListeners(clientRequestListeners, url) === false) {
        return;
      }
      if (isLocalhost(url.hostname)) {
        url.protocol = "http:";
        target = target === originalHttpsGet || target === originalHttpGet ? originalHttpGet : originalHttpRequest;
      }
      options.protocol = url.protocol;
      options.host = url.host;
      options.hostname = url.hostname;
      options.port = url.port;
      options.path = `${url.href.replace(url.origin, "")}`;
      options.href = url.href;
      if (options.agent && options.agent instanceof http.Agent && options.agent.protocol === "https:" && isLocalhost(url.hostname)) {
        options.agent = new http.Agent(options.agent.options || {});
      }
      args = [url, options, callback];
    }
    return Reflect.apply(target, ctx, args);
  };
}
function getHrefFromRequestOptions(options, protocol) {
  if (options.href) {
    return options.href;
  }
  if (options.host == null) {
    options.host = "localhost";
  }
  let { host, path: path2, port } = options;
  if (!host.includes(":") && port != null) {
    host += `:${port}`;
  }
  return `${protocol}://${host}${path2}`;
}
function notifyListeners(listeners, url) {
  for (const listener of listeners) {
    if (listener(url) === false) {
      return false;
    }
  }
}

// src/utils/url.js
function isEqualSearchParams(params1, params2) {
  const keys1 = Array.from(params1.keys());
  const keys2 = Array.from(params2.keys());
  if (keys1.length !== keys2.length) {
    return false;
  }
  for (const key of keys1) {
    const values1 = params1.getAll(key);
    const values2 = params2.getAll(key);
    if (values1.length !== values2.length) {
      return false;
    }
    for (const value of values1) {
      if (!values2.includes(value)) {
        return false;
      }
    }
  }
  return true;
}

// src/application-host/application-worker.js
import { syncBuiltinESMExports } from "module";
import { workerData } from "worker_threads";
var hostUrl = new URL(workerData.hostOrigin);
var serverPort = workerData.serverPort;
var _a;
var mocks = (_a = workerData.serializedMocks) == null ? void 0 : _a.map((mockData) => {
  mockData.originRegex = new RegExp(mockData.originRegex);
  mockData.pathRegex = new RegExp(mockData.pathRegex);
  mockData.search = new URLSearchParams(mockData.search);
  return mockData;
});
var messagePort = workerData.messagePort;
var originalCreateServer = http2.createServer;
var server;
messagePort.on(
  "message",
  async (msg) => {
    if (msg.type === "start") {
      try {
        await import(msg.main);
        messagePort.postMessage({
          type: "watch",
          paths: Array.from(global.sources)
        });
      } catch (err) {
        console.log(err);
        throw err;
      }
    }
  }
);
http2.createServer = new Proxy(http2.createServer, {
  apply(target, ctx, args) {
    server = Reflect.apply(target, ctx, args);
    server.on("error", (err) => {
      throw err;
    });
    server.on("listening", () => {
      messagePort.postMessage({ type: "started" });
    });
    server.listen = new Proxy(server.listen, {
      apply(target2, ctx2, args2) {
        if (typeof args2[0] === "object") {
          args2[0].port = serverPort;
          args2[0].host = "localhost";
        } else {
          if (typeof args2[0] === "number") {
            args2[0] = serverPort;
            if (typeof args2[1] === "string") {
              args2[1] = "localhost";
            }
          } else {
            args2 = [serverPort, "localhost", ...args2.slice(1)];
          }
        }
        return Reflect.apply(target2, ctx2, args2);
      }
    });
    http2.createServer = originalCreateServer;
    syncBuiltinESMExports();
    return server;
  }
});
interceptClientRequest((url) => {
  if (mocks) {
    for (const mock of mocks) {
      if (!mock.originRegex.test(url.origin) || !mock.ignoreSearch && mock.search && !isEqualSearchParams(url.searchParams, mock.search)) {
        continue;
      }
      if (mock.pathRegex.exec(url.pathname) != null) {
        const href = url.href;
        url.host = hostUrl.host;
        url.search = `?dvlpmock=${encodeURIComponent(href)}`;
        break;
      }
    }
  }
  return true;
});
syncBuiltinESMExports();

==> dvlp-15.0.0-beta.1.tgz: package/application-worker.js <==
import { createRequire as createRequireBecauseEsbuild } from 'module'; 
const require = createRequireBecauseEsbuild(import.meta.url);

// src/application-host/application-worker.js
import http2 from "http";

// src/utils/broken-named-exports.js
var broken_named_exports_default = {
  react: [
    "Children",
    "Component",
    "Fragment",
    "Profiler",
    "PureComponent",
    "StrictMode",
    "Suspense",
    "__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED",
    "cloneElement",
    "createContext",
    "createElement",
    "createFactory",
    "createRef",
    "forwardRef",
    "isValidElement",
    "lazy",
    "memo",
    "useCallback",
    "useContext",
    "useDebugValue",
    "useEffect",
    "useImperativeHandle",
    "useLayoutEffect",
    "useMemo",
    "useReducer",
    "useRef",
    "useState",
    "version"
  ],
  "react-dom": [
    "__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED",
    "createPortal",
    "findDOMNode",
    "flushSync",
    "hydrate",
    "render",
    "unmountComponentAtNode",
    "unstable_batchedUpdates",
    "unstable_createPortal",
    "unstable_renderSubtreeIntoContainer",
    "version"
  ],
  "react-is": ["isContextConsumer", "isValidElementType"]
};

// src/config.js
import path from "path";
import { pathToFileURL } from "url";
var DIR_NAME = ".dvlp";
var TESTING = process.env.NODE_ENV === "dvlptest" || process.env.CI != void 0;
var VERSION = "15.0.0-beta.1";
var dirPath = path.resolve(DIR_NAME);
var versionDirPath = path.join(dirPath, VERSION);
var applicationLoaderURL = pathToFileURL(
  path.join(versionDirPath, "app-loader.mjs")
);
var bundleDirName = path.join(DIR_NAME, VERSION, "bundled");
var bundleDirPath = path.resolve(bundleDirName);
var bundleDirMetaPath = path.join(bundleDirPath, "__meta__.json");
var defaultPort = process.env.PORT ? Number(process.env.PORT) : 8080;
var electronDirPath = path.join(versionDirPath, "electron");
var electronEntryURL = pathToFileURL(
  path.join(electronDirPath, "electron-entry.cjs")
);
var config = {
  activePort: defaultPort,
  applicationLoaderURL,
  brokenNamedExportsPackages: broken_named_exports_default,
  bundleDirPath,
  bundleDirMetaPath,
  bundleDirName,
  defaultPort,
  directories: [],
  dirPath,
  dvlpDirPath: path.resolve(DIR_NAME),
  electronDirPath,
  electronEntryURL,
  esbuildTargetByExtension: {
    ".js": "js",
    ".mjs": "js",
    ".cjs": "js",
    ".json": "json",
    ".jsx": "jsx",
    ".ts": "ts",
    ".tsx": "tsx",
    ".mts": "ts",
    ".cts": "ts"
  },
  extensionsByType: {
    css: [".pcss", ".sass", ".scss", ".less", ".styl", ".stylus", ".css"],
    html: [
      ".nunjs",
      ".nunjucks",
      ".hbs",
      ".handlebars",
      ".dust",
      ".html",
      ".htm"
    ],
    js: [".ts", ".mts", ".cts", ".tsx", ".jsx", ".mjs", ".cjs", ".js", ".json"]
  },
  jsMimeTypes: {
    "application/javascript": ["js", "mjs", "cjs", "jsx", "ts", "tsx"]
  },
  latency: 50,
  maxAge: "10m",
  reloadEndpoint: "/dvlpreload",
  serverStartTimeout: TESTING ? 4e3 : 1e4,
  testing: TESTING,
  typesByExtension: {
    ".css": "css",
    ".pcss": "css",
    ".sass": "css",
    ".scss": "css",
    ".less": "css",
    ".styl": "css",
    ".stylus": "css",
    ".html": "html",
    ".htm": "html",
    ".nunjs": "html",
    ".nunjucks": "html",
    ".hbs": "html",
    ".handlebars": "html",
    ".dust": "html",
    ".js": "js",
    ".mjs": "js",
    ".cjs": "js",
    ".json": "js",
    ".jsx": "js",
    ".ts": "js",
    ".tsx": "js",
    ".mts": "js",
    ".cts": "js"
  },
  version: VERSION,
  versionDirPath
};

// src/utils/is.js
import fs from "fs";
import util from "util";
var HAS_UTIL_IS_PROXY = util.types && util.types.isProxy !== void 0;
var RE_LOCALHOST = /localhost|127\.0\.0\.1/;
var realPath = "native" in fs.realpathSync && typeof fs.realpathSync.native === "function" ? fs.realpathSync.native : fs.realpathSync;
function isLocalhost(url) {
  return RE_LOCALHOST.test(url);
}
function isProxy(obj) {
  if (HAS_UTIL_IS_PROXY) {
    return util.types.isProxy(obj);
  } else {
    return obj instanceof Proxy;
  }
}

// src/utils/intercept-client-request.js
import http from "http";
import https from "https";
var clientRequestListeners = /* @__PURE__ */ new Set();
var originalHttpRequest = http.request;
var originalHttpGet = http.get;
var originalHttpsRequest = https.request;
var originalHttpsGet = https.get;
function interceptClientRequest(fn) {
  initInterceptClientRequest();
  clientRequestListeners.add(fn);
  return restoreClientRequest.bind(null, fn);
}
function initInterceptClientRequest() {
  if (!isProxy(http.request)) {
    http.request = new Proxy(http.request, {
      apply: clientRequestApplyTrap("http")
    });
    http.get = new Proxy(http.get, { apply: clientRequestApplyTrap("http") });
    https.request = new Proxy(https.request, {
      apply: clientRequestApplyTrap("https")
    });
    https.get = new Proxy(https.get, {
      apply: clientRequestApplyTrap("https")
    });
  }
}
function restoreClientRequest(fn) {
  clientRequestListeners.delete(fn);
  if (!clientRequestListeners.size) {
    http.request = originalHttpRequest;
    http.get = originalHttpGet;
    https.request = originalHttpsRequest;
    https.get = originalHttpsGet;
  }
}
function clientRequestApplyTrap(protocol) {
  return function apply(target, ctx, args) {
    if (clientRequestListeners.size > 0) {
      let [urlOrOptions, optionsOrCallback, callback] = args;
      let options;
      let url;
      if (typeof urlOrOptions === "string" || urlOrOptions instanceof URL) {
        url = new URL(urlOrOptions);
        options = optionsOrCallback;
      } else {
        url = new URL(getHrefFromRequestOptions(urlOrOptions, protocol));
        callback = optionsOrCallback;
        options = urlOrOptions;
      }
      if (notifyListeners(clientRequestListeners, url) === false) {
        return;
      }
      if (isLocalhost(url.hostname)) {
        url.protocol = "http:";
        target = target === originalHttpsGet || target === originalHttpGet ? originalHttpGet : originalHttpRequest;
      }
      options.protocol = url.protocol;
      options.host = url.host;
      options.hostname = url.hostname;
      options.port = url.port;
      options.path = `${url.href.replace(url.origin, "")}`;
      options.href = url.href;
      if (options.agent && options.agent instanceof http.Agent && options.agent.protocol === "https:" && isLocalhost(url.hostname)) {
        options.agent = new http.Agent(options.agent.options || {});
      }
      args = [url, options, callback];
    }
    return Reflect.apply(target, ctx, args);
  };
}
function getHrefFromRequestOptions(options, protocol) {
  if (options.href) {
    return options.href;
  }
  if (options.host == null) {
    options.host = "localhost";
  }
  let { host, path: path2, port } = options;
  if (!host.includes(":") && port != null) {
    host += `:${port}`;
  }
  return `${protocol}://${host}${path2}`;
}
function notifyListeners(listeners, url) {
  for (const listener of listeners) {
    if (listener(url) === false) {
      return false;
    }
  }
}

// src/utils/url.js
function isEqualSearchParams(params1, params2) {
  const keys1 = Array.from(params1.keys());
  const keys2 = Array.from(params2.keys());
  if (keys1.length !== keys2.length) {
    return false;
  }
  for (const key of keys1) {
    const values1 = params1.getAll(key);
    const values2 = params2.getAll(key);
    if (values1.length !== values2.length) {
      return false;
    }
    for (const value of values1) {
      if (!values2.includes(value)) {
        return false;
      }
    }
  }
  return true;
}

// src/application-host/application-worker.js
import { syncBuiltinESMExports } from "module";
import { workerData } from "worker_threads";
var hostUrl = new URL(workerData.hostOrigin);
var serverPort = workerData.serverPort;
var _a;
var mocks = (_a = workerData.serializedMocks) == null ? void 0 : _a.map((mockData) => {
  mockData.originRegex = new RegExp(mockData.originRegex);
  mockData.pathRegex = new RegExp(mockData.pathRegex);
  mockData.search = new URLSearchParams(mockData.search);
  return mockData;
});
var messagePort = workerData.messagePort;
var originalCreateServer = http2.createServer;
var server;
messagePort.on(
  "message",
  async (msg) => {
    if (msg.type === "start") {
      try {
        await import(msg.main);
        messagePort.postMessage({
          type: "watch",
          paths: Array.from(global.sources)
        });
      } catch (err) {
        console.log(err);
        throw err;
      }
    }
  }
);
http2.createServer = new Proxy(http2.createServer, {
  apply(target, ctx, args) {
    server = Reflect.apply(target, ctx, args);
    server.on("error", (err) => {
      throw err;
    });
    server.on("listening", () => {
      messagePort.postMessage({ type: "started" });
    });
    server.listen = new Proxy(server.listen, {
      apply(target2, ctx2, args2) {
        if (typeof args2[0] === "object") {
          args2[0].port = serverPort;
          args2[0].host = "localhost";
        } else {
          if (typeof args2[0] === "number") {
            args2[0] = serverPort;
            if (typeof args2[1] === "string") {
              args2[1] = "localhost";
            }
          } else {
            args2 = [serverPort, "localhost", ...args2.slice(1)];
          }
        }
        return Reflect.apply(target2, ctx2, args2);
      }
    });
    http2.createServer = originalCreateServer;
    syncBuiltinESMExports();
    return server;
  }
});
interceptClientRequest((url) => {
  if (mocks) {
    for (const mock of mocks) {
      if (!mock.originRegex.test(url.origin) || !mock.ignoreSearch && mock.search && !isEqualSearchParams(url.searchParams, mock.search)) {
        continue;
      }
      if (mock.pathRegex.exec(url.pathname) != null) {
        const href = url.href;
        url.host = hostUrl.host;
        url.search = `?dvlpmock=${encodeURIComponent(href)}`;
        break;
      }
    }
  }
  return true;
});
syncBuiltinESMExports();
